@@ -15,6 +15,7 @@
 ##############################################################################
 import inspect
 import os
+import typing
 import uuid
 from abc import ABC
 from collections import ChainMap, OrderedDict
@@ -23,6 +24,7 @@ import bluesky.plan_stubs as bps
 import bluesky.plans as bp
 import bluesky.preprocessors as bpp
 import numpy as np
+import pyFAI
 import yaml
 from bluesky.callbacks import LiveTable
 from xpdconf.conf import XPD_SHUTTER_CONF
@@ -914,8 +916,8 @@ class ScanPlan(ValidatedDictLike, YamlChainMap, ABC):
         )
         # bound_arguments.apply_defaults() # only valid in py 3.5
         complete_kwargs = bound_arguments.arguments
-        # remove place holder for [pe1c]
-        complete_kwargs.popitem(False)
+        # remove place holder for "dets"
+        complete_kwargs.pop("dets")
         # replace callable objects, with its func name
         for k, v in complete_kwargs.items():
             if callable(v):
@@ -969,3 +971,68 @@ class ScanPlan(ValidatedDictLike, YamlChainMap, ABC):
         arg_value_str = map(str, self.bound_arguments.values())
         fn = "_".join([self["sp_plan_name"]] + list(arg_value_str))
         return os.path.join(glbl["yaml_dir"], "scanplans", "%s.yml" % fn)
+
+
+def load_calibration_md(poni_file: str) -> dict:
+    """Load the calibration metadata in a dictionary from a .poni file.
+
+    Parameters
+    ----------
+    poni_file :
+        The path to the .poni file.
+
+    Returns
+    -------
+    calibration_md :
+        The metadata in a dictionary.
+    """
+    ai = pyFAI.load(poni_file)
+    return dict(ai.getPyFAI())
+
+
+def count_with_calib(detectors: list, num: int = 1, delay: float = None, *, calibration_md: dict = None,
+                     md: dict = None) -> typing.Generator:
+    """
+    Take one or more readings from detectors with shutter control and calibration metadata injection.
+
+    Parameters
+    ----------
+    detectors : list
+        list of 'readable' objects
+
+    num : integer, optional
+        number of readings to take; default is 1
+
+        If None, capture data until canceled
+
+    delay : iterable or scalar, optional
+        Time delay in seconds between successive readings; default is 0.
+
+    per_shot : callable, optional
+        hook for customizing action of inner loop (messages per step)
+        Expected signature ::
+
+           def f(detectors: Iterable[OphydObj]) -> Generator[Msg]:
+               ...
+
+    calibration_md :
+        The calibration data in a dictionary. If not applied, the function is a normal `bluesky.plans.count`.
+
+    md : dict, optional
+        metadata
+
+    Notes
+    -----
+    If ``delay`` is an iterable, it must have at least ``num - 1`` entries or
+    the plan will raise a ``ValueError`` during iteration.
+    """
+    if md is None:
+        md = dict()
+    if calibration_md is not None:
+        md["calibration_md"] = calibration_md
+    yield from open_shutter_stub()
+    plan = bp.count(detectors, num, delay, md=md)
+    bpp.subs_wrapper(plan, LiveTable(detectors))
+    sts = yield from plan
+    yield from close_shutter_stub()
+    return sts
